@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2009-2011 EPIPE Communications. All rights reserved.
+ * Copyright (c) 2009-2013 EPIPE Communications. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -48,8 +48,8 @@
  * on GNU/Linux.
  */
 
-#if defined(__linux__) || defined(__GLIBC__)
-/* GNU/Linux or GNU/kFreeBSD */
+#if defined(__linux__) || defined(__GLIBC__) || defined(__GNU__)
+/* GNU/Linux, GNU/kFreeBSD, and GNU/Hurd */
 #define	_GNU_SOURCE
 #define	_BSD_SOURCE
 #endif
@@ -149,33 +149,34 @@ static int	daemon(int, int);
 
 /* Command line arguments with their defaults */
 
-char *	cf_log = "daemon";  /* syslog facility or filename with a slash (/) */
-char *	cf_pidfile = _PATH_VARRUN PROGNAME ".pid";
-char *	cf_datadir = PATH_DOWNTIMEDBDIR;
-long	cf_sleep = 15;                 /* update time stamp every 15 seconds */
+static char *	cf_log = "daemon";    /* syslog facility or filename with / */
+static char *	cf_pidfile = _PATH_VARRUN PROGNAME ".pid";
+static char *	cf_datadir = PATH_DOWNTIMEDBDIR;
+static long	cf_sleep = 15;        /* update time stamp every 15 seconds */
 #ifdef HAVE_FUTIMES
-int	cf_fsync = 1;	      /* if true, fsync() stamp files after touching */
+static int	cf_fsync = 1;  /* set to fsync() stamp files after touching */
 #endif
-int	cf_downtimedb = 1;		       /* if true, update downtimedb */
-char *	cf_downtimedbfile = PATH_DOWNTIMEDBFILE;
+static int	cf_downtimedb = 1;            /* if true, update downtimedb */
+static char *	cf_downtimedbfile = PATH_DOWNTIMEDBFILE;
+static char *	cf_timefmt = FMT_DATETIME;
 
 /* Logging destination, determined from cf_log */
 
-int	cf_logfacility = 0;
-int	cf_logfd = -1;
+static int	cf_logfacility	=  0;
+static int	cf_logfd	= -1;
 
 /* Global variables */
 
-char *	ts_stamp = NULL;
-char *	ts_shutdown = NULL;
-char *	ts_boot = NULL;
-time_t	boottime = 0;
-time_t	starttime = 0;
+static char *	ts_stamp	= NULL;
+static char *	ts_shutdown	= NULL;
+static char *	ts_boot		= NULL;
+static time_t	boottime	= 0;
+static time_t	starttime	= 0;
 
 /* The following are set by the signal handler */
 
-volatile sig_atomic_t	exiting = 0;
-volatile sig_atomic_t	reopenlog = 0;
+static volatile sig_atomic_t	exiting	  = 0;
+static volatile sig_atomic_t	reopenlog = 0;
 
 /*
  * downtimed: system downtime monitoring and reporting daemon.
@@ -386,7 +387,7 @@ updatedowntimedb(time_t up, int crashed, time_t down)
 		logwr(LOG_ERR, "can not write to %s: %s", cf_downtimedbfile,
 		    strerror(errno));
 
-	/* ensure again that padding bytes are zero */
+	/* not really needed, but ensure again that padding bytes are zero */
 	memset(&dbent, 0, sizeof(struct downtimedb));
 
 	dbent.what = DOWNTIMEDB_WHAT_UP;
@@ -460,10 +461,10 @@ report()
 
 	if (have_shutdown) {
 		logwr(LOG_NOTICE, "system shutdown at %s",
-		    timestr_abs(sb_shutdown.st_mtime));
+		    timestr_abs(sb_shutdown.st_mtime, cf_timefmt, 0));
 	} else {
 		logwr(LOG_NOTICE, "system crashed at %s",
-		    timestr_abs(sb_stamp.st_mtime));
+		    timestr_abs(sb_stamp.st_mtime, cf_timefmt, 0));
 	}
 
 	logwr(LOG_NOTICE, "previous uptime was %s (%d seconds)",
@@ -664,7 +665,8 @@ logwr(int pri, const char *fmt, ...)
 			goto err;
 
 		if (asprintf(&str2, "%s: %s\n",
-		    timestr_abs(time((time_t *) NULL)), str) < 0) {
+		    timestr_abs(time((time_t *) NULL), cf_timefmt, 0), str)
+		    < 0) {
 			free(str);
 			goto err;
 		}
@@ -706,7 +708,7 @@ version()
 
 	puts(PROGNAME " " PROGVERSION " - system downtime reporting daemon\n");
 
-	puts("Copyright (c) 2009-2011 EPIPE Communications. "
+	puts("Copyright (c) 2009-2013 EPIPE Communications. "
 	    "All rights reserved.");
 	puts("This software is licensed under the terms and conditions of the "
 	    "FreeBSD");
@@ -739,7 +741,7 @@ parseargs(int argc, char *argv[])
 	int c;
 	char *p;
 
-	while ((c = getopt(argc, argv, "Dd:l:p:s:Svh?")) != -1) {
+	while ((c = getopt(argc, argv, "Dd:f:l:p:s:Svh?")) != -1) {
 		switch (c) {
 		case 'D':
 			cf_downtimedb = 0;
@@ -747,6 +749,9 @@ parseargs(int argc, char *argv[])
 		case 'd':
 			cf_datadir = optarg;
 			break;
+		case 'f':
+			cf_timefmt = optarg;
+			break;
 		case 'l':
 			cf_log = optarg;
 			break;
@@ -760,11 +765,11 @@ parseargs(int argc, char *argv[])
 			if ((p != NULL && *p != '\0') || errno != 0)
 				errx(EX_USAGE, "-s argument is not a number");
 			break;
-#ifdef HAVE_FUTIMES
 		case 'S':
+#ifdef HAVE_FUTIMES
 			cf_fsync = 0;
-			break;
 #endif
+			break;
 		case 'v':
 			version();
 			/* NOTREACHED */
