@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2009-2011 EPIPE Communications. All rights reserved.
+ * Copyright (c) 2009-2013 EPIPE Communications. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -96,8 +96,8 @@ downtimedb_read(int fd, struct downtimedb *buf)
 	int ret;
 
 	errno = 0;
-	if ((ret = read(fd, (void *)buf, sizeof(struct downtimedb))) <
-	    sizeof(struct downtimedb)) {
+	if ((ret = read(fd, (void *)buf, sizeof(struct downtimedb)))
+	    < sizeof(struct downtimedb)) {
 		if (ret == 0)
 			return (0);	/* eof */
 		else {
@@ -129,8 +129,8 @@ downtimedb_write(int fd, struct downtimedb *buf)
 #endif
 
 	errno = 0;
-	if (write(fd, (void *)buf, sizeof(struct downtimedb)) <
-	    sizeof(struct downtimedb))
+	if (write(fd, (void *)buf, sizeof(struct downtimedb))
+	    < sizeof(struct downtimedb))
 		return (-1);
 
 	return (0);
@@ -142,15 +142,15 @@ downtimedb_write(int fd, struct downtimedb *buf)
  */
 
 char *
-timestr_abs(time_t t)
+timestr_abs(time_t t, const char *fmt, int utc)
 {
-	static char str[100];
+	static char str[256];
 	struct tm *lt;
 
 	if (t != 0) {
-		if ((lt = localtime(&t)) == NULL)
+		if ((lt = (utc ? gmtime(&t) : localtime(&t))) == NULL)
 			goto err;
-		if (strftime(str, sizeof(str), "%F %T", lt) == 0)
+		if (strftime(str, sizeof(str), fmt, lt) == 0)
 			goto err;
 
 		return (str);
