@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2009-2011 EPIPE Communications. All rights reserved.
+ * Copyright (c) 2009-2013 EPIPE Communications. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -37,7 +37,7 @@
 /*
  * The structure of the downtime database file.
  *
- * This should provide a Y2K38 bug, 64 bit and endianness safe file format.
+ * The format is Y2K38 bug, 64 bit and endianness safe.
  * We need a portable format, because everything in the system could
  * change during the downtime. Someone could change the machine from
  * big-endian 32 bit architecture to 64 bit little-endian computer.
@@ -61,7 +61,9 @@ struct downtimedb {
 #define	DOWNTIMEDB_WHAT_SHUTDOWN	2
 #define	DOWNTIMEDB_WHAT_CRASH		3
 
-#if defined(__linux__) || defined(__FreeBSD_kernel__) || !defined(_PATH_VARDB)
+#if defined(__linux__) || \
+	(defined(__FreeBSD_kernel__) && !defined(__FreeBSD__)) \
+	|| defined(__GNU__) || !defined(_PATH_VARDB)
 #define	PATH_DOWNTIMEDBDIR	"/var/lib/downtimed/"
 #else
 #define	PATH_DOWNTIMEDBDIR	_PATH_VARDB "downtimed/"
@@ -69,11 +71,15 @@ struct downtimedb {
 
 #define	PATH_DOWNTIMEDBFILE	PATH_DOWNTIMEDBDIR "downtimedb"
 
+/* default absolute time format unless specified by user */
+
+#define FMT_DATETIME		"%F %T"
+
 /* Function prototypes */
 
 int	downtimedb_read(int, struct downtimedb *);
 int	downtimedb_write(int, struct downtimedb *);
-char *	timestr_abs(time_t);
+char *	timestr_abs(time_t, const char *, int);
 char *	timestr_int(time_t);
 
 /* eof */
