@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2009-2011 EPIPE Communications. All rights reserved.
+ * Copyright (c) 2009-2013 EPIPE Communications. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -86,9 +86,11 @@ static void	parseargs(int, char *[]);
 
 /* Command line arguments with their defaults */
 
-long	cf_sleep = 0;         /* adjust crash time according to sleep value */
-char *	cf_downtimedbfile = PATH_DOWNTIMEDBFILE;
-long	cf_n = -1;                 /* number of downtime records to display */
+static long	cf_sleep = 0; /* adjust crash time according to sleep value */
+static char *	cf_downtimedbfile = PATH_DOWNTIMEDBFILE;
+static long	cf_n = -1;         /* number of downtime records to display */
+static char *	cf_timefmt = FMT_DATETIME;
+static int	cf_utc = 0;                  /* set to display times in UTC */
 
 /*
  * downtimes: display system downtime records made by downtimed(8)
@@ -168,11 +170,16 @@ static void
 report(int64_t td, int crashed, int64_t tu)
 {
 	printf("%s %s -> ", crashed ? "crash" : "down ", 
-	    timestr_abs((time_t) td));
+	    timestr_abs((time_t) td, cf_timefmt, cf_utc));
 
-	printf("up %s ", timestr_abs((time_t) tu));
+	/* Note that the printf() above and below is intentionally split
+	   into two parts because timestr_abs() clobbers the returned
+	   static string on each call. */
 
-	/* timestr_int() returns string such as 21+06:11:38 or 06:11:38 */
+	printf("up %s ", timestr_abs((time_t) tu, cf_timefmt, cf_utc));
+
+	/* timestr_int() returns string representing a relative time (time
+	   period) such as 21+06:11:38 or 06:11:38 */
 
 	if (tu != 0 && td != 0)
 		printf("= %11s (%"PRIu64" s)\n",
@@ -188,7 +195,7 @@ usage()
 {
 
 	fputs("usage: " PROGNAME " [-v] [-d downtimedbfile] [-n num] "
-	    "[-s sleep]\n", stderr);
+	    "[-s sleep] [-u]\n", stderr);
 	exit(EX_USAGE);
 }
 
@@ -201,7 +208,7 @@ version()
 	puts(PROGNAME " " PROGVERSION " - display system downtime records "
 	    "made by downtimed(8)\n");
 
-	puts("Copyright (c) 2009-2011 EPIPE Communications. "
+	puts("Copyright (c) 2009-2013 EPIPE Communications. "
 	    "All rights reserved.");
 	puts("This software is licensed under the terms and conditions of the "
 	    "FreeBSD");
@@ -213,6 +220,8 @@ version()
 	printf("  downtimedbfile = %s\n", cf_downtimedbfile);
 	printf("  num = %ld\n", cf_n);
 	printf("  sleep = %ld\n", cf_sleep);
+	printf("  timefmt = %s\n", cf_timefmt);
+	printf("  utc = %d\n", cf_utc);
 
 #ifdef PACKAGE_URL
 	puts("\nSee the following web site for more information and updates:");
@@ -232,11 +241,14 @@ parseargs(int argc, char *argv[])
 	if (strlen(argv[0]) > 0 && argv[0][strlen(argv[0])-1] != 's')
 		cf_n = 1;
 
-	while ((c = getopt(argc, argv, "d:n:s:vh?")) != -1) {
+	while ((c = getopt(argc, argv, "d:f:n:s:uvh?")) != -1) {
 		switch (c) {
 		case 'd':
 			cf_downtimedbfile = optarg;
 			break;
+		case 'f':
+			cf_timefmt = optarg;
+			break;
 		case 'n':
 			p = NULL;
 			errno = 0;
@@ -251,6 +263,9 @@ parseargs(int argc, char *argv[])
 			if ((p != NULL && *p != '\0') || errno != 0)
 				errx(EX_USAGE, "-s argument is not a number");
 			break;
+		case 'u':
+			cf_utc = 1;
+			break;
 		case 'v':
 			version();
 			/* NOTREACHED */
